{% if request.resolver_match.url_name != 'index' %}
    <ol class="breadcrumb">
        <li>
            <a href="{% url 'geokey_webresources:index' %}">Extension home</a>
        </li>

        {% if request.resolver_match.url_name == 'all_webresources' %}
            <li class="active">Web resources</li>
        {% elif project %}
             <li>
                <a href="{% url 'geokey_webresources:all_webresources' project.id %}">Web resources</a>
            </li>
        {% endif %}

        {% if request.resolver_match.url_name == 'webresource_add' %}
            <li class="active">Add new web resource</li>
        {% elif request.resolver_match.url_name == 'single_webresource' %}
            <li class="active">Edit web resource</li>
        {% endif %}
    </ol>
{% endif %}
